==> aliyun-python-sdk-ivpd-1.0.2.tar.gz: aliyun-python-sdk-ivpd-1.0.2/aliyunsdkivpd/request/v20190625/RecolorImageRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkivpd.endpoint import endpoint_data

class RecolorImageRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'ivpd', '2019-06-25', 'RecolorImage','ivpd')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ColorTemplates(self):
		return self.get_body_params().get('ColorTemplates')

	def set_ColorTemplates(self,ColorTemplates):
		for i in range(len(ColorTemplates)):	
			if ColorTemplates[i].get('Color') is not None:
				self.add_body_params('ColorTemplate.' + str(i + 1) + '.Color' , ColorTemplates[i].get('Color'))


	def get_Url(self):
		return self.get_body_params().get('Url')

	def set_Url(self,Url):
		self.add_body_params('Url', Url)

	def get_Mode(self):
		return self.get_body_params().get('Mode')

	def set_Mode(self,Mode):
		self.add_body_params('Mode', Mode)

	def get_ColorCount(self):
		return self.get_body_params().get('ColorCount')

	def set_ColorCount(self,ColorCount):
		self.add_body_params('ColorCount', ColorCount)

	def get_RefUrl(self):
		return self.get_body_params().get('RefUrl')

	def set_RefUrl(self,RefUrl):
		self.add_body_params('RefUrl', RefUrl)

==> aliyun-python-sdk-ivpd-1.0.5.tar.gz: aliyun-python-sdk-ivpd-1.0.5/aliyunsdkivpd/request/v20190625/RecolorImageRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkivpd.endpoint import endpoint_data

class RecolorImageRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'ivpd', '2019-06-25', 'RecolorImage')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ColorTemplates(self):
		return self.get_body_params().get('ColorTemplates')

	def set_ColorTemplates(self,ColorTemplates):
		for i in range(len(ColorTemplates)):	
			if ColorTemplates[i].get('Color') is not None:
				self.add_body_params('ColorTemplate.' + str(i + 1) + '.Color' , ColorTemplates[i].get('Color'))


	def get_Url(self):
		return self.get_body_params().get('Url')

	def set_Url(self,Url):
		self.add_body_params('Url', Url)

	def get_Mode(self):
		return self.get_body_params().get('Mode')

	def set_Mode(self,Mode):
		self.add_body_params('Mode', Mode)

	def get_ColorCount(self):
		return self.get_body_params().get('ColorCount')

	def set_ColorCount(self,ColorCount):
		self.add_body_params('ColorCount', ColorCount)

	def get_RefUrl(self):
		return self.get_body_params().get('RefUrl')

	def set_RefUrl(self,RefUrl):
		self.add_body_params('RefUrl', RefUrl)
